Client

Struct Client 

pub struct Client { /* private fields */ }

Implementations

Source

impl Client

pub fn new(socket_path: Option<&str>) -> Client

pub async fn connect(&self) -> Result<(), Error>

connect to the docker host. Note that you don’t necessarily need to call connect. The client automatically connects to the Docker host on the first request if connect is not called before.

Source

impl Client